// MobileNavbar.jsx
"use client"
import React, { useState } from "react";
import { motion, AnimatePresence } from "framer-motion";
import Link from "next/link";
import LoginBtn from "../header/LoginBtn";
import PostButton from "./PostButton";

const MobileNavbar = ({ menu }) => {
  const [sideNav, setSideNav] = useState(false);
  const [openSubmenu, setOpenSubmenu] = useState(null);

  const toggleSubmenu = (index) => {
    if (openSubmenu === index) {
      setOpenSubmenu(null);
    } else {
      setOpenSubmenu(index);
    }
  };

  return (
    <div className="lg:hidden sticky top-0 bg-white z-50">
      <div className="flex justify-between items-center p-4">
        <Link href={"/"}><img src="/logo-jamin.png" alt="" className='w-[148px] h-[49px]' /></Link>
        <span
          className="bg-primary rounded-md p-2"
          onClick={() => setSideNav(true)}
        >
          <img src="/header/hamburger.svg" alt="" className="w-10" />
        </span>
      </div>
      <AnimatePresence>
        {sideNav && (
          <motion.div
            key="sideNav"
            initial={{ opacity: 0 }}
            animate={{ opacity: 1 }}
            exit={{ opacity: 1 }}
            onClick={() => setSideNav(false)}
            className="lg:hidden z-30 fixed top-0 left-0 h-screen w-full flex justify-end bg-black/50"
          >
            <motion.div
              initial={{ x: "100vw" }}
              animate={{ x: 0 }}
              exit={{ x: "100vw" }}
              transition={{
                ease: "linear",
                duration: 0.2,
              }}
              onClick={(e) => e.stopPropagation()}
              className="bg-white rounded-md w-3/4 lg:hidden overflow-y-auto px-8 pt-4 h-full"
            >
              <img src="/logo-jamin.png" alt="" className='w-[148px] h-[49px]' />
              <ul className="flex flex-col mt-8">
                {menu && menu.map((item, index) => (
                  <li className="border-t" key={item.title}>
                    <div className="flex justify-between items-center py-3 px-5">
                      <Link
                        href={item.to}
                        className="block hover:text-primary cursor-pointer text-base font-medium"
                        onClick={() => {
                          if (!item.subMenu) setSideNav(false);
                        }}
                      >
                        {item.title}
                      </Link>
                      {item.subMenu && (
                        <button
                          onClick={() => toggleSubmenu(index)}
                          className="p-2"
                        >
                          {openSubmenu === index ? "▲" : "▼"}
                        </button>
                      )}
                    </div>
                    {item.subMenu && openSubmenu === index && (
                      <ul className="bg-gray-100 py-2">
                        {item.subMenu.map(subItem => (
                          <li key={subItem.title}>
                            <Link
                              href={subItem.to}
                              className="block px-8 py-2 text-sm text-gray-700 hover:bg-gray-200"
                              onClick={() => setSideNav(false)}
                            >
                              {subItem.title}
                            </Link>
                          </li>
                        ))}
                      </ul>
                    )}
                  </li>
                ))}
              </ul>
              <div className="flex justify-between mt-8 mb-4 items-center">
                <LoginBtn />
                <img src="/header/customer-support.png" alt="" className="w-8 h-8" />
              </div>
              <PostButton />
            </motion.div>
          </motion.div>
        )}
      </AnimatePresence>
    </div>
  );
};

export default MobileNavbar;